@@ -539,7 +539,7 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 			gok_log_x ("using name: %s.", 
 				pStringAttributeValue);
 			/* use the name if no display name */
-			pStringAttributeValue = pAccessMethod->Name;
+			pStringAttributeValue = (unsigned char *)pAccessMethod->Name;
 		}
 		else
 		{
@@ -548,7 +548,7 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 		}
 	}
 		
-	strcpy (pAccessMethod->DisplayName, (gchar *)pStringAttributeValue);
+	strcpy (pAccessMethod->DisplayName, _((gchar *)pStringAttributeValue));
 
 	/* read the UI for the access method */
 	gok_scanner_read_description (pDoc, pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
@@ -993,14 +993,14 @@ gboolean gok_scanner_read_description (xmlDoc* pDoc, xmlNode* pNode, GokAccessMe
 	if (pNode = gok_scanner_find_node (pNode, (const xmlChar *) "description", gok_scanner_get_lang (),
 					   NULL)) {
 		pStringDescription = xmlNodeListGetString (pDoc, pNode->xmlChildrenNode, 1);
-		strncpy (pAccessMethod->Description, (gchar *)pStringDescription, MAX_DESCRIPTION_TEXT);
+		g_strlcpy (pAccessMethod->Description, _((gchar *)pStringDescription), MAX_DESCRIPTION_TEXT);
 		gok_log ("read access method description: [%s]", pStringDescription);
 		xmlFree (pStringDescription);
 		gok_log_leave();
 		return TRUE;
 	}
 	else {
-		strncpy (pAccessMethod->Description, (gchar *)"error reading description", MAX_DESCRIPTION_TEXT);
+		g_strlcpy (pAccessMethod->Description, (gchar*)_("error reading description"), MAX_DESCRIPTION_TEXT);
 		gok_log_leave();
 		return FALSE;
 	}
