@@ -42,6 +42,7 @@
 #include "gok-log.h"
 #include "main.h"
 #include "gok-gconf-keys.h"
+#include "gok-gconf.h"
 
 /* pointer to the settings dialog window */
 static GtkWidget* m_pWindowSettings;
@@ -337,6 +338,7 @@ void on_button_cancel (GtkButton* pButton, gpointer user_data)
 void on_button_help (GtkButton* pButton, gpointer user_data)
 {
 	GtkWidget* pNotebook;
+	const char* help_link_id = NULL;
 	
 	pNotebook = glade_xml_get_widget (m_pXML, "notebook1");
 	if (pNotebook == NULL)
@@ -348,33 +350,36 @@ void on_button_help (GtkButton* pButton, gpointer user_data)
 	switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (pNotebook)))
 	{
 		case 0:
-			gnome_help_display ("gok.xml","gok-settings-appearance", NULL);
+			help_link_id = "gok-prefs-appearance";
 			break;
 			
 		case 1:
-			gnome_help_display ("gok.xml", "gok-settings-keyboard", NULL);
+			help_link_id = "gok-keyboards";
 			break;
 			
 		case 2:
-			gnome_help_display ("gok.xml", "gok-settings-actions", NULL);
+			help_link_id = "gok-prefs-Actions";
 			break;
 			
 		case 3:
- 			gnome_help_display ("gok.xml", "gok-settings-feedback", NULL);
+			help_link_id = "gok-prefs-Feedback";
 			break;
 
 		case 4:
-			gnome_help_display ("gok.xml", "gok-settings-accessmethods",
-                                            NULL);
+			help_link_id = "gok-prefs-Access-Methods";
 			break;
 			
 		case 5:
-			gnome_help_display ("gok.xml", "gok-settings-prediction", NULL);
+			help_link_id = "gok-prefs-Prediction";
 			break;
 			
 		default:
 			break;
 	}
+	if (help_link_id)
+	{
+		gnome_help_display_desktop (NULL, "gok", "gok.xml", help_link_id, NULL);
+	}
 }
 
 /**
