@@ -100,7 +100,7 @@ void gok_main_mousebutton_listener (gint button, gint state, long mods, long tim
 void gok_main_close (void);
 gboolean gok_main_get_use_geometry (void);
 void gok_main_get_geometry (GdkRectangle* pRectangle);
-void gok_main_update_struts (gint width, gint height);
+void gok_main_update_struts (gint width, gint height, gint x, gint y);
 void gok_main_set_wm_dock (gboolean is_dock);
 
 #ifdef __cplusplus
